UI/SplashScreen.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 4021
195a471c327b
diff -r ac84ac3c0f05 -r f0cb7579c0b4 UI/SplashScreen.py
--- a/UI/SplashScreen.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/UI/SplashScreen.py	Sat Jul 05 12:13:23 2014 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a splashscreen for eric5.
+Module implementing a splashscreen for eric6.
 """
 
 from __future__ import unicode_literals
@@ -16,12 +16,12 @@
 from PyQt5.QtGui import QPixmap, QColor
 from PyQt5.QtWidgets import QApplication, QSplashScreen
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class SplashScreen(QSplashScreen):
     """
     Class implementing a splashscreen for eric5.
     """
     def __init__(self):
         """
@@ -56,7 +56,7 @@
 
 class NoneSplashScreen(object):
     """
-    Class implementing a "None" splashscreen for eric5.
+    Class implementing a "None" splashscreen for eric6.
     
     This class implements the same interface as the real splashscreen,
     but simply does nothing.
@@ -16,12 +16,12 @@
 class SplashScreen(QSplashScreen):
     """
-    Class implementing a splashscreen for eric5.
+    Class implementing a splashscreen for eric6.
     """
     def __init__(self):

eric ide

mercurial